@@ -44,7 +44,6 @@
 #define MAX_NUM_LOGS             10
 #define MAX_NUM_DPY_LINES        300
 #define MAX_DPY_NUM_CHARS        200
-#define DEF_NUM_LOGS             3
 
 #define FRMT_HEADING             1
 #define FRMT_NORMAL              2
@@ -106,22 +105,24 @@ get_month (const char *str)
 
 	for (i = 0; i < 12; i++) {
 		if (monthname[i] == NULL) {
-			GDate *date;
+			struct tm tm = {0};
 			char buf[256];
 
-			date = g_date_new_dmy (1, i+1, 2000 /* bogus */);
+			tm.tm_mday = 1;
+			tm.tm_year = 2000 /* bogus */;
+			tm.tm_mon = i;
 
-			if (g_date_strftime (buf, sizeof (buf), "%b", date) <= 0) {
+			/* Note: we don't want utf-8 here, we WANT the
+			 * current locale! */
+			if (strftime (buf, sizeof (buf), "%b", &tm) <= 0) {
 				/* eek, just use C locale cuz we're screwed */
 				monthname[i] = g_strndup (C_monthname[i], 3);
 			} else {
 				monthname[i] = g_strdup (buf);
 			}
-
-			g_date_free (date);
 		}
 
-		if (g_strcasecmp (str, monthname[i]) == 0) {
+		if (g_ascii_strcasecmp (str, monthname[i]) == 0) {
 			return i;
 		}
 	}
@@ -144,18 +145,22 @@ get_month (const char *str)
 				if (setlocale (LC_TIME, locales[j]) == NULL) {
 					strcpy (buf, "");
 				} else {
-					GDate *date;
+					struct tm tm = {0};
 
-					date = g_date_new_dmy (1, i+1, 2000 /* bogus */);
+					tm.tm_mday = 1;
+					tm.tm_year = 2000 /* bogus */;
+					tm.tm_mon = i;
 
-					if (g_date_strftime (buf, sizeof (buf), "%b", date) <= 0) {
+
+					if (strftime (buf, sizeof (buf), "%b",
+						      &tm) <= 0) {
 						strcpy (buf, "");
 					}
+				}
 
-					if (old_locale != NULL) {
-						setlocale (LC_TIME, old_locale);
-						g_free (old_locale);
-					}
+				if (old_locale != NULL) {
+					setlocale (LC_TIME, old_locale);
+					g_free (old_locale);
 				}
 
 				name = g_strdup (buf);
@@ -165,7 +170,7 @@ get_month (const char *str)
 
 			if (name != NULL &&
 			    name[0] != '\0' &&
-			    g_strcasecmp (str, name) == 0) {
+			    g_ascii_strcasecmp (str, name) == 0) {
 				return i;
 			}
 		}
@@ -526,7 +531,12 @@ ReadPageDown (Log * lg, Page * pg, gboolean exec_actions)
       if (ch == EOF)
       {
 	 if (ln == 0)
-	    pg->prev->islastpage = TRUE;
+	   {
+	     if (pg->prev != NULL)
+	       pg->prev->islastpage = TRUE;
+	     else
+	       pg->islastpage = TRUE; 
+	   }
 	 else
 	   pg->islastpage = TRUE;
 	 ungetc (ch, fp);
@@ -580,6 +590,10 @@ ParseLine (char *buff, LogLine * line)
    char scratch[1024];
    int i;
 
+   /* just copy as a whole line to be the default */
+   strncpy (line->message, buff, MAX_WIDTH);
+   line->message[MAX_WIDTH-1] = '\0';
+
    token = strtok (buff, " ");
    if (token == NULL) return;
    /* This is not a good assumption I don't think, especially
@@ -602,8 +616,6 @@ ParseLine (char *buff, LogLine * line)
 
    if (i == 12)
    {
-      strncpy (line->message, buff, MAX_WIDTH);
-      line->message[MAX_WIDTH-1] = '\0';
       line->month = -1;
       line->date = -1;
       line->hour = -1;
